aboutsummaryrefslogtreecommitdiffhomepage
path: root/csharp/src
diff options
context:
space:
mode:
authorGravatar Jon Skeet <jonskeet@google.com>2015-07-17 08:26:04 +0100
committerGravatar Jon Skeet <jonskeet@google.com>2015-07-17 08:26:04 +0100
commit59eeebee870332ea2b9085688ba524c69311f662 (patch)
tree4300e8aeaff6a3b706c398496a692f5ed25f43b7 /csharp/src
parent0f442a7533b1d06ce0092b28f10af481b99e1369 (diff)
First pass at the big rename from ProtocolBuffers to Google.Protobuf.
We'll see what I've missed when CI fails...
Diffstat (limited to 'csharp/src')
-rw-r--r--csharp/src/AddressBook/AddressBook.csproj4
-rw-r--r--csharp/src/Google.Protobuf.JsonDump/Google.Protobuf.JsonDump.csproj (renamed from csharp/src/ProtoDump/ProtoDump.csproj)10
-rw-r--r--csharp/src/Google.Protobuf.JsonDump/Program.cs (renamed from csharp/src/ProtoDump/Program.cs)4
-rw-r--r--csharp/src/Google.Protobuf.JsonDump/Properties/AssemblyInfo.cs (renamed from csharp/src/ProtoDump/Properties/AssemblyInfo.cs)0
-rw-r--r--csharp/src/Google.Protobuf.JsonDump/app.config (renamed from csharp/src/ProtoDump/app.config)0
-rw-r--r--csharp/src/Google.Protobuf.Test/ByteStringTest.cs (renamed from csharp/src/ProtocolBuffers.Test/ByteStringTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/CodedInputStreamExtensions.cs (renamed from csharp/src/ProtocolBuffers.Test/CodedInputStreamExtensions.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/CodedInputStreamTest.cs (renamed from csharp/src/ProtocolBuffers.Test/CodedInputStreamTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/CodedOutputStreamTest.cs (renamed from csharp/src/ProtocolBuffers.Test/CodedOutputStreamTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/Collections/MapFieldTest.cs (renamed from csharp/src/ProtocolBuffers.Test/Collections/MapFieldTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/Collections/RepeatedFieldTest.cs (renamed from csharp/src/ProtocolBuffers.Test/Collections/RepeatedFieldTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/DeprecatedMemberTest.cs (renamed from csharp/src/ProtocolBuffers.Test/DeprecatedMemberTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/EqualityTester.cs (renamed from csharp/src/ProtocolBuffers.Test/EqualityTester.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/FieldCodecTest.cs (renamed from csharp/src/ProtocolBuffers.Test/FieldCodecTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/GeneratedMessageTest.cs (renamed from csharp/src/ProtocolBuffers.Test/GeneratedMessageTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/Google.Protobuf.Test.csproj (renamed from csharp/src/ProtocolBuffers.Test/ProtocolBuffers.Test.csproj)8
-rw-r--r--csharp/src/Google.Protobuf.Test/IssuesTest.cs (renamed from csharp/src/ProtocolBuffers.Test/IssuesTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/JsonFormatterTest.cs (renamed from csharp/src/ProtocolBuffers.Test/JsonFormatterTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/Properties/AppManifest.xml (renamed from csharp/src/ProtocolBuffers.Test/Properties/AppManifest.xml)0
-rw-r--r--csharp/src/Google.Protobuf.Test/Properties/AssemblyInfo.cs (renamed from csharp/src/ProtocolBuffers.Test/Properties/AssemblyInfo.cs)4
-rw-r--r--csharp/src/Google.Protobuf.Test/Reflection/DescriptorsTest.cs (renamed from csharp/src/ProtocolBuffers.Test/Reflection/DescriptorsTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/SampleEnum.cs (renamed from csharp/src/ProtocolBuffers.Test/SampleEnum.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/SampleMessages.cs (renamed from csharp/src/ProtocolBuffers.Test/SampleMessages.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/TestCornerCases.cs (renamed from csharp/src/ProtocolBuffers.Test/TestCornerCases.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/TestProtos/MapUnittestProto3.cs (renamed from csharp/src/ProtocolBuffers.Test/TestProtos/MapUnittestProto3.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/TestProtos/UnittestImportProto3.cs (renamed from csharp/src/ProtocolBuffers.Test/TestProtos/UnittestImportProto3.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/TestProtos/UnittestImportPublicProto3.cs (renamed from csharp/src/ProtocolBuffers.Test/TestProtos/UnittestImportPublicProto3.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/TestProtos/UnittestIssues.cs (renamed from csharp/src/ProtocolBuffers.Test/TestProtos/UnittestIssues.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/TestProtos/UnittestProto3.cs (renamed from csharp/src/ProtocolBuffers.Test/TestProtos/UnittestProto3.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/TestProtos/UnittestWellKnownTypes.cs (renamed from csharp/src/ProtocolBuffers.Test/TestProtos/UnittestWellKnownTypes.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/WellKnownTypes/WrappersTest.cs (renamed from csharp/src/ProtocolBuffers.Test/WellKnownTypes/WrappersTest.cs)0
-rw-r--r--csharp/src/Google.Protobuf.Test/packages.config (renamed from csharp/src/ProtocolBuffers.Test/packages.config)0
-rw-r--r--csharp/src/Google.Protobuf.sln (renamed from csharp/src/ProtocolBuffers.sln)6
-rw-r--r--csharp/src/Google.Protobuf/ByteArray.cs (renamed from csharp/src/ProtocolBuffers/ByteArray.cs)0
-rw-r--r--csharp/src/Google.Protobuf/ByteString.cs (renamed from csharp/src/ProtocolBuffers/ByteString.cs)0
-rw-r--r--csharp/src/Google.Protobuf/CodedInputStream.cs (renamed from csharp/src/ProtocolBuffers/CodedInputStream.cs)0
-rw-r--r--csharp/src/Google.Protobuf/CodedOutputStream.ComputeSize.cs (renamed from csharp/src/ProtocolBuffers/CodedOutputStream.ComputeSize.cs)0
-rw-r--r--csharp/src/Google.Protobuf/CodedOutputStream.cs (renamed from csharp/src/ProtocolBuffers/CodedOutputStream.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Collections/MapField.cs (renamed from csharp/src/ProtocolBuffers/Collections/MapField.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Collections/ReadOnlyDictionary.cs (renamed from csharp/src/ProtocolBuffers/Collections/ReadOnlyDictionary.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Collections/RepeatedField.cs (renamed from csharp/src/ProtocolBuffers/Collections/RepeatedField.cs)0
-rw-r--r--csharp/src/Google.Protobuf/FieldCodec.cs (renamed from csharp/src/ProtocolBuffers/FieldCodec.cs)0
-rw-r--r--csharp/src/Google.Protobuf/FrameworkPortability.cs (renamed from csharp/src/ProtocolBuffers/FrameworkPortability.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Freezable.cs (renamed from csharp/src/ProtocolBuffers/Freezable.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Google.Protobuf.csproj (renamed from csharp/src/ProtocolBuffers/ProtocolBuffers.csproj)2
-rw-r--r--csharp/src/Google.Protobuf/Google.Protobuf.nuspec (renamed from csharp/src/ProtocolBuffers/Google.Protobuf.nuspec)0
-rw-r--r--csharp/src/Google.Protobuf/IMessage.cs (renamed from csharp/src/ProtocolBuffers/IMessage.cs)0
-rw-r--r--csharp/src/Google.Protobuf/InvalidProtocolBufferException.cs (renamed from csharp/src/ProtocolBuffers/InvalidProtocolBufferException.cs)0
-rw-r--r--csharp/src/Google.Protobuf/JsonFormatter.cs (renamed from csharp/src/ProtocolBuffers/JsonFormatter.cs)0
-rw-r--r--csharp/src/Google.Protobuf/LimitedInputStream.cs (renamed from csharp/src/ProtocolBuffers/LimitedInputStream.cs)0
-rw-r--r--csharp/src/Google.Protobuf/MessageExtensions.cs (renamed from csharp/src/ProtocolBuffers/MessageExtensions.cs)0
-rw-r--r--csharp/src/Google.Protobuf/MessageParser.cs (renamed from csharp/src/ProtocolBuffers/MessageParser.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Properties/AssemblyInfo.cs (renamed from csharp/src/ProtocolBuffers/Properties/AssemblyInfo.cs)4
-rw-r--r--csharp/src/Google.Protobuf/Reflection/DescriptorBase.cs (renamed from csharp/src/ProtocolBuffers/Reflection/DescriptorBase.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/DescriptorPool.cs (renamed from csharp/src/ProtocolBuffers/Reflection/DescriptorPool.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/DescriptorProtoFile.cs (renamed from csharp/src/ProtocolBuffers/Reflection/DescriptorProtoFile.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/DescriptorUtil.cs (renamed from csharp/src/ProtocolBuffers/Reflection/DescriptorUtil.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/DescriptorValidationException.cs (renamed from csharp/src/ProtocolBuffers/Reflection/DescriptorValidationException.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/EnumDescriptor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/EnumDescriptor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/EnumValueDescriptor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/EnumValueDescriptor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/FieldAccessorBase.cs (renamed from csharp/src/ProtocolBuffers/Reflection/FieldAccessorBase.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/FieldAccessorTable.cs (renamed from csharp/src/ProtocolBuffers/Reflection/FieldAccessorTable.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/FieldDescriptor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/FieldDescriptor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/FieldType.cs (renamed from csharp/src/ProtocolBuffers/Reflection/FieldType.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/FileDescriptor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/FileDescriptor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/IDescriptor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/IDescriptor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/IFieldAccessor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/IFieldAccessor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/MapFieldAccessor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/MapFieldAccessor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/MessageDescriptor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/MessageDescriptor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/MethodDescriptor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/MethodDescriptor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/OneofAccessor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/OneofAccessor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/OneofDescriptor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/OneofDescriptor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/PackageDescriptor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/PackageDescriptor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/PartialClasses.cs (renamed from csharp/src/ProtocolBuffers/Reflection/PartialClasses.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/ReflectionUtil.cs (renamed from csharp/src/ProtocolBuffers/Reflection/ReflectionUtil.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/RepeatedFieldAccessor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/RepeatedFieldAccessor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/ServiceDescriptor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/ServiceDescriptor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/Reflection/SingleFieldAccessor.cs (renamed from csharp/src/ProtocolBuffers/Reflection/SingleFieldAccessor.cs)0
-rw-r--r--csharp/src/Google.Protobuf/ThrowHelper.cs (renamed from csharp/src/ProtocolBuffers/ThrowHelper.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WellKnownTypes/Any.cs (renamed from csharp/src/ProtocolBuffers/WellKnownTypes/Any.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WellKnownTypes/Api.cs (renamed from csharp/src/ProtocolBuffers/WellKnownTypes/Api.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WellKnownTypes/Duration.cs (renamed from csharp/src/ProtocolBuffers/WellKnownTypes/Duration.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WellKnownTypes/Empty.cs (renamed from csharp/src/ProtocolBuffers/WellKnownTypes/Empty.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WellKnownTypes/FieldMask.cs (renamed from csharp/src/ProtocolBuffers/WellKnownTypes/FieldMask.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WellKnownTypes/SourceContext.cs (renamed from csharp/src/ProtocolBuffers/WellKnownTypes/SourceContext.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WellKnownTypes/Struct.cs (renamed from csharp/src/ProtocolBuffers/WellKnownTypes/Struct.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WellKnownTypes/Timestamp.cs (renamed from csharp/src/ProtocolBuffers/WellKnownTypes/Timestamp.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WellKnownTypes/Type.cs (renamed from csharp/src/ProtocolBuffers/WellKnownTypes/Type.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WellKnownTypes/Wrappers.cs (renamed from csharp/src/ProtocolBuffers/WellKnownTypes/Wrappers.cs)0
-rw-r--r--csharp/src/Google.Protobuf/WireFormat.cs (renamed from csharp/src/ProtocolBuffers/WireFormat.cs)0
-rw-r--r--csharp/src/ProtocolBuffers.Test/Properties/OutOfBrowserSettings.xml7
-rw-r--r--csharp/src/packages/repositories.config3
92 files changed, 22 insertions, 30 deletions
diff --git a/csharp/src/AddressBook/AddressBook.csproj b/csharp/src/AddressBook/AddressBook.csproj
index b338af9c..bae43b40 100644
--- a/csharp/src/AddressBook/AddressBook.csproj
+++ b/csharp/src/AddressBook/AddressBook.csproj
@@ -53,9 +53,9 @@
<Compile Include="Properties\AssemblyInfo.cs" />
</ItemGroup>
<ItemGroup>
- <ProjectReference Include="..\ProtocolBuffers\ProtocolBuffers.csproj">
+ <ProjectReference Include="..\Google.Protobuf\Google.Protobuf.csproj">
<Project>{6908BDCE-D925-43F3-94AC-A531E6DF2591}</Project>
- <Name>ProtocolBuffers</Name>
+ <Name>Google.Protobuf</Name>
</ProjectReference>
</ItemGroup>
<ItemGroup>
diff --git a/csharp/src/ProtoDump/ProtoDump.csproj b/csharp/src/Google.Protobuf.JsonDump/Google.Protobuf.JsonDump.csproj
index a74067e4..c3c9d277 100644
--- a/csharp/src/ProtoDump/ProtoDump.csproj
+++ b/csharp/src/Google.Protobuf.JsonDump/Google.Protobuf.JsonDump.csproj
@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
+<?xml version="1.0" encoding="utf-8"?>
<Project ToolsVersion="4.0" DefaultTargets="Build" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
<PropertyGroup>
<EnvironmentFlavor>CLIENTPROFILE</EnvironmentFlavor>
@@ -10,8 +10,8 @@
<ProjectGuid>{D7282E99-2DC3-405B-946F-177DB2FD2AE2}</ProjectGuid>
<OutputType>Exe</OutputType>
<AppDesignerFolder>Properties</AppDesignerFolder>
- <RootNamespace>Google.Protobuf.ProtoDump</RootNamespace>
- <AssemblyName>ProtoDump</AssemblyName>
+ <RootNamespace>Google.Protobuf.JsonDump</RootNamespace>
+ <AssemblyName>Google.Protobuf.JsonDump</AssemblyName>
<TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
<FileAlignment>512</FileAlignment>
<TargetFrameworkProfile>Client</TargetFrameworkProfile>
@@ -48,9 +48,9 @@
<Compile Include="Properties\AssemblyInfo.cs" />
</ItemGroup>
<ItemGroup>
- <ProjectReference Include="..\ProtocolBuffers\ProtocolBuffers.csproj">
+ <ProjectReference Include="..\Google.Protobuf\Google.Protobuf.csproj">
<Project>{6908BDCE-D925-43F3-94AC-A531E6DF2591}</Project>
- <Name>ProtocolBuffers</Name>
+ <Name>Google.Protobuf</Name>
</ProjectReference>
</ItemGroup>
<ItemGroup>
diff --git a/csharp/src/ProtoDump/Properties/AssemblyInfo.cs b/csharp/src/Google.Protobuf.JsonDump/Properties/AssemblyInfo.cs
index a8ce8eae..a8ce8eae 100644
--- a/csharp/src/ProtoDump/Properties/AssemblyInfo.cs
+++ b/csharp/src/Google.Protobuf.JsonDump/Properties/AssemblyInfo.cs
diff --git a/csharp/src/ProtoDump/app.config b/csharp/src/Google.Protobuf.JsonDump/app.config
index e2a5a187..e2a5a187 100644
--- a/csharp/src/ProtoDump/app.config
+++ b/csharp/src/Google.Protobuf.JsonDump/app.config
diff --git a/csharp/src/ProtocolBuffers.Test/ByteStringTest.cs b/csharp/src/Google.Protobuf.Test/ByteStringTest.cs
index 685e130a..685e130a 100644
--- a/csharp/src/ProtocolBuffers.Test/ByteStringTest.cs
+++ b/csharp/src/Google.Protobuf.Test/ByteStringTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/CodedInputStreamExtensions.cs b/csharp/src/Google.Protobuf.Test/CodedInputStreamExtensions.cs
index 408c7cb9..408c7cb9 100644
--- a/csharp/src/ProtocolBuffers.Test/CodedInputStreamExtensions.cs
+++ b/csharp/src/Google.Protobuf.Test/CodedInputStreamExtensions.cs
diff --git a/csharp/src/ProtocolBuffers.Test/CodedInputStreamTest.cs b/csharp/src/Google.Protobuf.Test/CodedInputStreamTest.cs
index fa88d407..fa88d407 100644
--- a/csharp/src/ProtocolBuffers.Test/CodedInputStreamTest.cs
+++ b/csharp/src/Google.Protobuf.Test/CodedInputStreamTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/CodedOutputStreamTest.cs b/csharp/src/Google.Protobuf.Test/CodedOutputStreamTest.cs
index c3d92a66..c3d92a66 100644
--- a/csharp/src/ProtocolBuffers.Test/CodedOutputStreamTest.cs
+++ b/csharp/src/Google.Protobuf.Test/CodedOutputStreamTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/Collections/MapFieldTest.cs b/csharp/src/Google.Protobuf.Test/Collections/MapFieldTest.cs
index 46d3bd9a..46d3bd9a 100644
--- a/csharp/src/ProtocolBuffers.Test/Collections/MapFieldTest.cs
+++ b/csharp/src/Google.Protobuf.Test/Collections/MapFieldTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/Collections/RepeatedFieldTest.cs b/csharp/src/Google.Protobuf.Test/Collections/RepeatedFieldTest.cs
index 25be7731..25be7731 100644
--- a/csharp/src/ProtocolBuffers.Test/Collections/RepeatedFieldTest.cs
+++ b/csharp/src/Google.Protobuf.Test/Collections/RepeatedFieldTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/DeprecatedMemberTest.cs b/csharp/src/Google.Protobuf.Test/DeprecatedMemberTest.cs
index 34d5b9f9..34d5b9f9 100644
--- a/csharp/src/ProtocolBuffers.Test/DeprecatedMemberTest.cs
+++ b/csharp/src/Google.Protobuf.Test/DeprecatedMemberTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/EqualityTester.cs b/csharp/src/Google.Protobuf.Test/EqualityTester.cs
index a669baba..a669baba 100644
--- a/csharp/src/ProtocolBuffers.Test/EqualityTester.cs
+++ b/csharp/src/Google.Protobuf.Test/EqualityTester.cs
diff --git a/csharp/src/ProtocolBuffers.Test/FieldCodecTest.cs b/csharp/src/Google.Protobuf.Test/FieldCodecTest.cs
index c6ed2a21..c6ed2a21 100644
--- a/csharp/src/ProtocolBuffers.Test/FieldCodecTest.cs
+++ b/csharp/src/Google.Protobuf.Test/FieldCodecTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/GeneratedMessageTest.cs b/csharp/src/Google.Protobuf.Test/GeneratedMessageTest.cs
index acb20b15..acb20b15 100644
--- a/csharp/src/ProtocolBuffers.Test/GeneratedMessageTest.cs
+++ b/csharp/src/Google.Protobuf.Test/GeneratedMessageTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/ProtocolBuffers.Test.csproj b/csharp/src/Google.Protobuf.Test/Google.Protobuf.Test.csproj
index a425ad84..6d8b4de2 100644
--- a/csharp/src/ProtocolBuffers.Test/ProtocolBuffers.Test.csproj
+++ b/csharp/src/Google.Protobuf.Test/Google.Protobuf.Test.csproj
@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
+<?xml version="1.0" encoding="utf-8"?>
<Project ToolsVersion="4.0" DefaultTargets="Build" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
<PropertyGroup>
<Configuration Condition=" '$(Configuration)' == '' ">Debug</Configuration>
@@ -13,7 +13,7 @@
<TargetFrameworkVersion>v4.5</TargetFrameworkVersion>
<FileAlignment>512</FileAlignment>
<SignAssembly>true</SignAssembly>
- <AssemblyOriginatorKeyFile>..\..\keys\Google.ProtocolBuffers.snk</AssemblyOriginatorKeyFile>
+ <AssemblyOriginatorKeyFile>..\..\keys\Google.Protobuf.snk</AssemblyOriginatorKeyFile>
<OldToolsVersion>3.5</OldToolsVersion>
<TargetFrameworkProfile>
</TargetFrameworkProfile>
@@ -97,9 +97,9 @@
<Compile Include="WellKnownTypes\WrappersTest.cs" />
</ItemGroup>
<ItemGroup>
- <ProjectReference Include="..\ProtocolBuffers\ProtocolBuffers.csproj">
+ <ProjectReference Include="..\Google.Protobuf\Google.Protobuf.csproj">
<Project>{6908BDCE-D925-43F3-94AC-A531E6DF2591}</Project>
- <Name>ProtocolBuffers</Name>
+ <Name>Google.Protobuf</Name>
</ProjectReference>
</ItemGroup>
<ItemGroup>
diff --git a/csharp/src/ProtocolBuffers.Test/IssuesTest.cs b/csharp/src/Google.Protobuf.Test/IssuesTest.cs
index b5ad34ae..b5ad34ae 100644
--- a/csharp/src/ProtocolBuffers.Test/IssuesTest.cs
+++ b/csharp/src/Google.Protobuf.Test/IssuesTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/JsonFormatterTest.cs b/csharp/src/Google.Protobuf.Test/JsonFormatterTest.cs
index 5441bf47..5441bf47 100644
--- a/csharp/src/ProtocolBuffers.Test/JsonFormatterTest.cs
+++ b/csharp/src/Google.Protobuf.Test/JsonFormatterTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/Properties/AppManifest.xml b/csharp/src/Google.Protobuf.Test/Properties/AppManifest.xml
index a9552327..a9552327 100644
--- a/csharp/src/ProtocolBuffers.Test/Properties/AppManifest.xml
+++ b/csharp/src/Google.Protobuf.Test/Properties/AppManifest.xml
diff --git a/csharp/src/ProtocolBuffers.Test/Properties/AssemblyInfo.cs b/csharp/src/Google.Protobuf.Test/Properties/AssemblyInfo.cs
index bfa1f05e..b551388c 100644
--- a/csharp/src/ProtocolBuffers.Test/Properties/AssemblyInfo.cs
+++ b/csharp/src/Google.Protobuf.Test/Properties/AssemblyInfo.cs
@@ -7,11 +7,11 @@ using System.Runtime.InteropServices;
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("ProtocolBuffers.Test")]
+[assembly: AssemblyTitle("Google.Protobuf.Test")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("")]
-[assembly: AssemblyProduct("ProtocolBuffers.Test")]
+[assembly: AssemblyProduct("Google.Protobuf.Test")]
[assembly: AssemblyCopyright("Copyright � 2008")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
diff --git a/csharp/src/ProtocolBuffers.Test/Reflection/DescriptorsTest.cs b/csharp/src/Google.Protobuf.Test/Reflection/DescriptorsTest.cs
index 0db01a5e..0db01a5e 100644
--- a/csharp/src/ProtocolBuffers.Test/Reflection/DescriptorsTest.cs
+++ b/csharp/src/Google.Protobuf.Test/Reflection/DescriptorsTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/SampleEnum.cs b/csharp/src/Google.Protobuf.Test/SampleEnum.cs
index 77447afa..77447afa 100644
--- a/csharp/src/ProtocolBuffers.Test/SampleEnum.cs
+++ b/csharp/src/Google.Protobuf.Test/SampleEnum.cs
diff --git a/csharp/src/ProtocolBuffers.Test/SampleMessages.cs b/csharp/src/Google.Protobuf.Test/SampleMessages.cs
index 8a9c7f86..8a9c7f86 100644
--- a/csharp/src/ProtocolBuffers.Test/SampleMessages.cs
+++ b/csharp/src/Google.Protobuf.Test/SampleMessages.cs
diff --git a/csharp/src/ProtocolBuffers.Test/TestCornerCases.cs b/csharp/src/Google.Protobuf.Test/TestCornerCases.cs
index b270a6f9..b270a6f9 100644
--- a/csharp/src/ProtocolBuffers.Test/TestCornerCases.cs
+++ b/csharp/src/Google.Protobuf.Test/TestCornerCases.cs
diff --git a/csharp/src/ProtocolBuffers.Test/TestProtos/MapUnittestProto3.cs b/csharp/src/Google.Protobuf.Test/TestProtos/MapUnittestProto3.cs
index 5f6eae0c..5f6eae0c 100644
--- a/csharp/src/ProtocolBuffers.Test/TestProtos/MapUnittestProto3.cs
+++ b/csharp/src/Google.Protobuf.Test/TestProtos/MapUnittestProto3.cs
diff --git a/csharp/src/ProtocolBuffers.Test/TestProtos/UnittestImportProto3.cs b/csharp/src/Google.Protobuf.Test/TestProtos/UnittestImportProto3.cs
index 3875a4c3..3875a4c3 100644
--- a/csharp/src/ProtocolBuffers.Test/TestProtos/UnittestImportProto3.cs
+++ b/csharp/src/Google.Protobuf.Test/TestProtos/UnittestImportProto3.cs
diff --git a/csharp/src/ProtocolBuffers.Test/TestProtos/UnittestImportPublicProto3.cs b/csharp/src/Google.Protobuf.Test/TestProtos/UnittestImportPublicProto3.cs
index 048ae5e9..048ae5e9 100644
--- a/csharp/src/ProtocolBuffers.Test/TestProtos/UnittestImportPublicProto3.cs
+++ b/csharp/src/Google.Protobuf.Test/TestProtos/UnittestImportPublicProto3.cs
diff --git a/csharp/src/ProtocolBuffers.Test/TestProtos/UnittestIssues.cs b/csharp/src/Google.Protobuf.Test/TestProtos/UnittestIssues.cs
index c68c67fb..c68c67fb 100644
--- a/csharp/src/ProtocolBuffers.Test/TestProtos/UnittestIssues.cs
+++ b/csharp/src/Google.Protobuf.Test/TestProtos/UnittestIssues.cs
diff --git a/csharp/src/ProtocolBuffers.Test/TestProtos/UnittestProto3.cs b/csharp/src/Google.Protobuf.Test/TestProtos/UnittestProto3.cs
index 67c42708..67c42708 100644
--- a/csharp/src/ProtocolBuffers.Test/TestProtos/UnittestProto3.cs
+++ b/csharp/src/Google.Protobuf.Test/TestProtos/UnittestProto3.cs
diff --git a/csharp/src/ProtocolBuffers.Test/TestProtos/UnittestWellKnownTypes.cs b/csharp/src/Google.Protobuf.Test/TestProtos/UnittestWellKnownTypes.cs
index af7d83ba..af7d83ba 100644
--- a/csharp/src/ProtocolBuffers.Test/TestProtos/UnittestWellKnownTypes.cs
+++ b/csharp/src/Google.Protobuf.Test/TestProtos/UnittestWellKnownTypes.cs
diff --git a/csharp/src/ProtocolBuffers.Test/WellKnownTypes/WrappersTest.cs b/csharp/src/Google.Protobuf.Test/WellKnownTypes/WrappersTest.cs
index ad88c4eb..ad88c4eb 100644
--- a/csharp/src/ProtocolBuffers.Test/WellKnownTypes/WrappersTest.cs
+++ b/csharp/src/Google.Protobuf.Test/WellKnownTypes/WrappersTest.cs
diff --git a/csharp/src/ProtocolBuffers.Test/packages.config b/csharp/src/Google.Protobuf.Test/packages.config
index c7653992..c7653992 100644
--- a/csharp/src/ProtocolBuffers.Test/packages.config
+++ b/csharp/src/Google.Protobuf.Test/packages.config
diff --git a/csharp/src/ProtocolBuffers.sln b/csharp/src/Google.Protobuf.sln
index c5708fd5..a290ae82 100644
--- a/csharp/src/ProtocolBuffers.sln
+++ b/csharp/src/Google.Protobuf.sln
@@ -2,13 +2,13 @@ Microsoft Visual Studio Solution File, Format Version 12.00
# Visual Studio 14
VisualStudioVersion = 14.0.22823.1
MinimumVisualStudioVersion = 10.0.40219.1
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "ProtocolBuffers", "ProtocolBuffers\ProtocolBuffers.csproj", "{6908BDCE-D925-43F3-94AC-A531E6DF2591}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Google.Protobuf", "Google.Protobuf\Google.Protobuf.csproj", "{6908BDCE-D925-43F3-94AC-A531E6DF2591}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "ProtocolBuffers.Test", "ProtocolBuffers.Test\ProtocolBuffers.Test.csproj", "{DD01ED24-3750-4567-9A23-1DB676A15610}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Google.Protobuf.Test", "Google.Protobuf.Test\Google.Protobuf.Test.csproj", "{DD01ED24-3750-4567-9A23-1DB676A15610}"
EndProject
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "AddressBook", "AddressBook\AddressBook.csproj", "{A31F5FB2-4FF3-432A-B35B-5CD203606311}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "ProtoDump", "ProtoDump\ProtoDump.csproj", "{D7282E99-2DC3-405B-946F-177DB2FD2AE2}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Google.Protobuf.JsonDump", "Google.Protobuf.JsonDump\Google.Protobuf.JsonDump.csproj", "{D7282E99-2DC3-405B-946F-177DB2FD2AE2}"
EndProject
Global
GlobalSection(SolutionConfigurationPlatforms) = preSolution
diff --git a/csharp/src/ProtocolBuffers/ByteArray.cs b/csharp/src/Google.Protobuf/ByteArray.cs
index 69b6ef8d..69b6ef8d 100644
--- a/csharp/src/ProtocolBuffers/ByteArray.cs
+++ b/csharp/src/Google.Protobuf/ByteArray.cs
diff --git a/csharp/src/ProtocolBuffers/ByteString.cs b/csharp/src/Google.Protobuf/ByteString.cs
index 329f47f6..329f47f6 100644
--- a/csharp/src/ProtocolBuffers/ByteString.cs
+++ b/csharp/src/Google.Protobuf/ByteString.cs
diff --git a/csharp/src/ProtocolBuffers/CodedInputStream.cs b/csharp/src/Google.Protobuf/CodedInputStream.cs
index ef7cf114..ef7cf114 100644
--- a/csharp/src/ProtocolBuffers/CodedInputStream.cs
+++ b/csharp/src/Google.Protobuf/CodedInputStream.cs
diff --git a/csharp/src/ProtocolBuffers/CodedOutputStream.ComputeSize.cs b/csharp/src/Google.Protobuf/CodedOutputStream.ComputeSize.cs
index bf221c9c..bf221c9c 100644
--- a/csharp/src/ProtocolBuffers/CodedOutputStream.ComputeSize.cs
+++ b/csharp/src/Google.Protobuf/CodedOutputStream.ComputeSize.cs
diff --git a/csharp/src/ProtocolBuffers/CodedOutputStream.cs b/csharp/src/Google.Protobuf/CodedOutputStream.cs
index b91d6d70..b91d6d70 100644
--- a/csharp/src/ProtocolBuffers/CodedOutputStream.cs
+++ b/csharp/src/Google.Protobuf/CodedOutputStream.cs
diff --git a/csharp/src/ProtocolBuffers/Collections/MapField.cs b/csharp/src/Google.Protobuf/Collections/MapField.cs
index f5e4fd3a..f5e4fd3a 100644
--- a/csharp/src/ProtocolBuffers/Collections/MapField.cs
+++ b/csharp/src/Google.Protobuf/Collections/MapField.cs
diff --git a/csharp/src/ProtocolBuffers/Collections/ReadOnlyDictionary.cs b/csharp/src/Google.Protobuf/Collections/ReadOnlyDictionary.cs
index 84360667..84360667 100644
--- a/csharp/src/ProtocolBuffers/Collections/ReadOnlyDictionary.cs
+++ b/csharp/src/Google.Protobuf/Collections/ReadOnlyDictionary.cs
diff --git a/csharp/src/ProtocolBuffers/Collections/RepeatedField.cs b/csharp/src/Google.Protobuf/Collections/RepeatedField.cs
index 9bab41ea..9bab41ea 100644
--- a/csharp/src/ProtocolBuffers/Collections/RepeatedField.cs
+++ b/csharp/src/Google.Protobuf/Collections/RepeatedField.cs
diff --git a/csharp/src/ProtocolBuffers/FieldCodec.cs b/csharp/src/Google.Protobuf/FieldCodec.cs
index 85462787..85462787 100644
--- a/csharp/src/ProtocolBuffers/FieldCodec.cs
+++ b/csharp/src/Google.Protobuf/FieldCodec.cs
diff --git a/csharp/src/ProtocolBuffers/FrameworkPortability.cs b/csharp/src/Google.Protobuf/FrameworkPortability.cs
index 082eb2e1..082eb2e1 100644
--- a/csharp/src/ProtocolBuffers/FrameworkPortability.cs
+++ b/csharp/src/Google.Protobuf/FrameworkPortability.cs
diff --git a/csharp/src/ProtocolBuffers/Freezable.cs b/csharp/src/Google.Protobuf/Freezable.cs
index d16e1b42..d16e1b42 100644
--- a/csharp/src/ProtocolBuffers/Freezable.cs
+++ b/csharp/src/Google.Protobuf/Freezable.cs
diff --git a/csharp/src/ProtocolBuffers/ProtocolBuffers.csproj b/csharp/src/Google.Protobuf/Google.Protobuf.csproj
index 402d6612..431668fe 100644
--- a/csharp/src/ProtocolBuffers/ProtocolBuffers.csproj
+++ b/csharp/src/Google.Protobuf/Google.Protobuf.csproj
@@ -15,7 +15,7 @@
<TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
<FileAlignment>512</FileAlignment>
<SignAssembly>true</SignAssembly>
- <AssemblyOriginatorKeyFile>..\..\keys\Google.ProtocolBuffers.snk</AssemblyOriginatorKeyFile>
+ <AssemblyOriginatorKeyFile>..\..\keys\Google.Protobuf.snk</AssemblyOriginatorKeyFile>
<OldToolsVersion>3.5</OldToolsVersion>
<MinimumVisualStudioVersion>10.0</MinimumVisualStudioVersion>
</PropertyGroup>
diff --git a/csharp/src/ProtocolBuffers/Google.Protobuf.nuspec b/csharp/src/Google.Protobuf/Google.Protobuf.nuspec
index 9b5e1c83..9b5e1c83 100644
--- a/csharp/src/ProtocolBuffers/Google.Protobuf.nuspec
+++ b/csharp/src/Google.Protobuf/Google.Protobuf.nuspec
diff --git a/csharp/src/ProtocolBuffers/IMessage.cs b/csharp/src/Google.Protobuf/IMessage.cs
index 8c4a4aaf..8c4a4aaf 100644
--- a/csharp/src/ProtocolBuffers/IMessage.cs
+++ b/csharp/src/Google.Protobuf/IMessage.cs
diff --git a/csharp/src/ProtocolBuffers/InvalidProtocolBufferException.cs b/csharp/src/Google.Protobuf/InvalidProtocolBufferException.cs
index 4f89347d..4f89347d 100644
--- a/csharp/src/ProtocolBuffers/InvalidProtocolBufferException.cs
+++ b/csharp/src/Google.Protobuf/InvalidProtocolBufferException.cs
diff --git a/csharp/src/ProtocolBuffers/JsonFormatter.cs b/csharp/src/Google.Protobuf/JsonFormatter.cs
index dacc7221..dacc7221 100644
--- a/csharp/src/ProtocolBuffers/JsonFormatter.cs
+++ b/csharp/src/Google.Protobuf/JsonFormatter.cs
diff --git a/csharp/src/ProtocolBuffers/LimitedInputStream.cs b/csharp/src/Google.Protobuf/LimitedInputStream.cs
index f11d19d9..f11d19d9 100644
--- a/csharp/src/ProtocolBuffers/LimitedInputStream.cs
+++ b/csharp/src/Google.Protobuf/LimitedInputStream.cs
diff --git a/csharp/src/ProtocolBuffers/MessageExtensions.cs b/csharp/src/Google.Protobuf/MessageExtensions.cs
index ee2863d1..ee2863d1 100644
--- a/csharp/src/ProtocolBuffers/MessageExtensions.cs
+++ b/csharp/src/Google.Protobuf/MessageExtensions.cs
diff --git a/csharp/src/ProtocolBuffers/MessageParser.cs b/csharp/src/Google.Protobuf/MessageParser.cs
index 5407de06..5407de06 100644
--- a/csharp/src/ProtocolBuffers/MessageParser.cs
+++ b/csharp/src/Google.Protobuf/MessageParser.cs
diff --git a/csharp/src/ProtocolBuffers/Properties/AssemblyInfo.cs b/csharp/src/Google.Protobuf/Properties/AssemblyInfo.cs
index c6918e70..a957e8b3 100644
--- a/csharp/src/ProtocolBuffers/Properties/AssemblyInfo.cs
+++ b/csharp/src/Google.Protobuf/Properties/AssemblyInfo.cs
@@ -37,11 +37,11 @@ using System.Runtime.CompilerServices;
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("ProtocolBuffers")]
+[assembly: AssemblyTitle("Google.Protobuf")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("")]
-[assembly: AssemblyProduct("ProtocolBuffers")]
+[assembly: AssemblyProduct("Google.Protobuf")]
[assembly: AssemblyCopyright("Copyright © 2008")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
diff --git a/csharp/src/ProtocolBuffers/Reflection/DescriptorBase.cs b/csharp/src/Google.Protobuf/Reflection/DescriptorBase.cs
index 0300cd58..0300cd58 100644
--- a/csharp/src/ProtocolBuffers/Reflection/DescriptorBase.cs
+++ b/csharp/src/Google.Protobuf/Reflection/DescriptorBase.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/DescriptorPool.cs b/csharp/src/Google.Protobuf/Reflection/DescriptorPool.cs
index 157ea400..157ea400 100644
--- a/csharp/src/ProtocolBuffers/Reflection/DescriptorPool.cs
+++ b/csharp/src/Google.Protobuf/Reflection/DescriptorPool.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/DescriptorProtoFile.cs b/csharp/src/Google.Protobuf/Reflection/DescriptorProtoFile.cs
index c87969b9..c87969b9 100644
--- a/csharp/src/ProtocolBuffers/Reflection/DescriptorProtoFile.cs
+++ b/csharp/src/Google.Protobuf/Reflection/DescriptorProtoFile.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/DescriptorUtil.cs b/csharp/src/Google.Protobuf/Reflection/DescriptorUtil.cs
index af31dfb1..af31dfb1 100644
--- a/csharp/src/ProtocolBuffers/Reflection/DescriptorUtil.cs
+++ b/csharp/src/Google.Protobuf/Reflection/DescriptorUtil.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/DescriptorValidationException.cs b/csharp/src/Google.Protobuf/Reflection/DescriptorValidationException.cs
index 143671db..143671db 100644
--- a/csharp/src/ProtocolBuffers/Reflection/DescriptorValidationException.cs
+++ b/csharp/src/Google.Protobuf/Reflection/DescriptorValidationException.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/EnumDescriptor.cs b/csharp/src/Google.Protobuf/Reflection/EnumDescriptor.cs
index bf8f8c83..bf8f8c83 100644
--- a/csharp/src/ProtocolBuffers/Reflection/EnumDescriptor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/EnumDescriptor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/EnumValueDescriptor.cs b/csharp/src/Google.Protobuf/Reflection/EnumValueDescriptor.cs
index 29833c4a..29833c4a 100644
--- a/csharp/src/ProtocolBuffers/Reflection/EnumValueDescriptor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/EnumValueDescriptor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/FieldAccessorBase.cs b/csharp/src/Google.Protobuf/Reflection/FieldAccessorBase.cs
index 39a63b47..39a63b47 100644
--- a/csharp/src/ProtocolBuffers/Reflection/FieldAccessorBase.cs
+++ b/csharp/src/Google.Protobuf/Reflection/FieldAccessorBase.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/FieldAccessorTable.cs b/csharp/src/Google.Protobuf/Reflection/FieldAccessorTable.cs
index 24fcbc64..24fcbc64 100644
--- a/csharp/src/ProtocolBuffers/Reflection/FieldAccessorTable.cs
+++ b/csharp/src/Google.Protobuf/Reflection/FieldAccessorTable.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/FieldDescriptor.cs b/csharp/src/Google.Protobuf/Reflection/FieldDescriptor.cs
index 3d9d0d75..3d9d0d75 100644
--- a/csharp/src/ProtocolBuffers/Reflection/FieldDescriptor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/FieldDescriptor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/FieldType.cs b/csharp/src/Google.Protobuf/Reflection/FieldType.cs
index 41fa702d..41fa702d 100644
--- a/csharp/src/ProtocolBuffers/Reflection/FieldType.cs
+++ b/csharp/src/Google.Protobuf/Reflection/FieldType.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/FileDescriptor.cs b/csharp/src/Google.Protobuf/Reflection/FileDescriptor.cs
index db393480..db393480 100644
--- a/csharp/src/ProtocolBuffers/Reflection/FileDescriptor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/FileDescriptor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/IDescriptor.cs b/csharp/src/Google.Protobuf/Reflection/IDescriptor.cs
index 6506db1b..6506db1b 100644
--- a/csharp/src/ProtocolBuffers/Reflection/IDescriptor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/IDescriptor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/IFieldAccessor.cs b/csharp/src/Google.Protobuf/Reflection/IFieldAccessor.cs
index 3f4f05f4..3f4f05f4 100644
--- a/csharp/src/ProtocolBuffers/Reflection/IFieldAccessor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/IFieldAccessor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/MapFieldAccessor.cs b/csharp/src/Google.Protobuf/Reflection/MapFieldAccessor.cs
index 317fbd8d..317fbd8d 100644
--- a/csharp/src/ProtocolBuffers/Reflection/MapFieldAccessor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/MapFieldAccessor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/MessageDescriptor.cs b/csharp/src/Google.Protobuf/Reflection/MessageDescriptor.cs
index b6351d36..b6351d36 100644
--- a/csharp/src/ProtocolBuffers/Reflection/MessageDescriptor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/MessageDescriptor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/MethodDescriptor.cs b/csharp/src/Google.Protobuf/Reflection/MethodDescriptor.cs
index 0c9c6949..0c9c6949 100644
--- a/csharp/src/ProtocolBuffers/Reflection/MethodDescriptor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/MethodDescriptor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/OneofAccessor.cs b/csharp/src/Google.Protobuf/Reflection/OneofAccessor.cs
index 7a11d36b..7a11d36b 100644
--- a/csharp/src/ProtocolBuffers/Reflection/OneofAccessor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/OneofAccessor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/OneofDescriptor.cs b/csharp/src/Google.Protobuf/Reflection/OneofDescriptor.cs
index e92dc8bb..e92dc8bb 100644
--- a/csharp/src/ProtocolBuffers/Reflection/OneofDescriptor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/OneofDescriptor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/PackageDescriptor.cs b/csharp/src/Google.Protobuf/Reflection/PackageDescriptor.cs
index e547d834..e547d834 100644
--- a/csharp/src/ProtocolBuffers/Reflection/PackageDescriptor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/PackageDescriptor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/PartialClasses.cs b/csharp/src/Google.Protobuf/Reflection/PartialClasses.cs
index c7ed4342..c7ed4342 100644
--- a/csharp/src/ProtocolBuffers/Reflection/PartialClasses.cs
+++ b/csharp/src/Google.Protobuf/Reflection/PartialClasses.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/ReflectionUtil.cs b/csharp/src/Google.Protobuf/Reflection/ReflectionUtil.cs
index d0dc3e8b..d0dc3e8b 100644
--- a/csharp/src/ProtocolBuffers/Reflection/ReflectionUtil.cs
+++ b/csharp/src/Google.Protobuf/Reflection/ReflectionUtil.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/RepeatedFieldAccessor.cs b/csharp/src/Google.Protobuf/Reflection/RepeatedFieldAccessor.cs
index 0ada7567..0ada7567 100644
--- a/csharp/src/ProtocolBuffers/Reflection/RepeatedFieldAccessor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/RepeatedFieldAccessor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/ServiceDescriptor.cs b/csharp/src/Google.Protobuf/Reflection/ServiceDescriptor.cs
index cc0a5010..cc0a5010 100644
--- a/csharp/src/ProtocolBuffers/Reflection/ServiceDescriptor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/ServiceDescriptor.cs
diff --git a/csharp/src/ProtocolBuffers/Reflection/SingleFieldAccessor.cs b/csharp/src/Google.Protobuf/Reflection/SingleFieldAccessor.cs
index 8c24e46e..8c24e46e 100644
--- a/csharp/src/ProtocolBuffers/Reflection/SingleFieldAccessor.cs
+++ b/csharp/src/Google.Protobuf/Reflection/SingleFieldAccessor.cs
diff --git a/csharp/src/ProtocolBuffers/ThrowHelper.cs b/csharp/src/Google.Protobuf/ThrowHelper.cs
index 62d9ea60..62d9ea60 100644
--- a/csharp/src/ProtocolBuffers/ThrowHelper.cs
+++ b/csharp/src/Google.Protobuf/ThrowHelper.cs
diff --git a/csharp/src/ProtocolBuffers/WellKnownTypes/Any.cs b/csharp/src/Google.Protobuf/WellKnownTypes/Any.cs
index 64d52ac5..64d52ac5 100644
--- a/csharp/src/ProtocolBuffers/WellKnownTypes/Any.cs
+++ b/csharp/src/Google.Protobuf/WellKnownTypes/Any.cs
diff --git a/csharp/src/ProtocolBuffers/WellKnownTypes/Api.cs b/csharp/src/Google.Protobuf/WellKnownTypes/Api.cs
index 1e2506a4..1e2506a4 100644
--- a/csharp/src/ProtocolBuffers/WellKnownTypes/Api.cs
+++ b/csharp/src/Google.Protobuf/WellKnownTypes/Api.cs
diff --git a/csharp/src/ProtocolBuffers/WellKnownTypes/Duration.cs b/csharp/src/Google.Protobuf/WellKnownTypes/Duration.cs
index fbc9c007..fbc9c007 100644
--- a/csharp/src/ProtocolBuffers/WellKnownTypes/Duration.cs
+++ b/csharp/src/Google.Protobuf/WellKnownTypes/Duration.cs
diff --git a/csharp/src/ProtocolBuffers/WellKnownTypes/Empty.cs b/csharp/src/Google.Protobuf/WellKnownTypes/Empty.cs
index c2681e29..c2681e29 100644
--- a/csharp/src/ProtocolBuffers/WellKnownTypes/Empty.cs
+++ b/csharp/src/Google.Protobuf/WellKnownTypes/Empty.cs
diff --git a/csharp/src/ProtocolBuffers/WellKnownTypes/FieldMask.cs b/csharp/src/Google.Protobuf/WellKnownTypes/FieldMask.cs
index 310c0d21..310c0d21 100644
--- a/csharp/src/ProtocolBuffers/WellKnownTypes/FieldMask.cs
+++ b/csharp/src/Google.Protobuf/WellKnownTypes/FieldMask.cs
diff --git a/csharp/src/ProtocolBuffers/WellKnownTypes/SourceContext.cs b/csharp/src/Google.Protobuf/WellKnownTypes/SourceContext.cs
index ee60fbe9..ee60fbe9 100644
--- a/csharp/src/ProtocolBuffers/WellKnownTypes/SourceContext.cs
+++ b/csharp/src/Google.Protobuf/WellKnownTypes/SourceContext.cs
diff --git a/csharp/src/ProtocolBuffers/WellKnownTypes/Struct.cs b/csharp/src/Google.Protobuf/WellKnownTypes/Struct.cs
index 99f88a96..99f88a96 100644
--- a/csharp/src/ProtocolBuffers/WellKnownTypes/Struct.cs
+++ b/csharp/src/Google.Protobuf/WellKnownTypes/Struct.cs
diff --git a/csharp/src/ProtocolBuffers/WellKnownTypes/Timestamp.cs b/csharp/src/Google.Protobuf/WellKnownTypes/Timestamp.cs
index e3bb3c37..e3bb3c37 100644
--- a/csharp/src/ProtocolBuffers/WellKnownTypes/Timestamp.cs
+++ b/csharp/src/Google.Protobuf/WellKnownTypes/Timestamp.cs
diff --git a/csharp/src/ProtocolBuffers/WellKnownTypes/Type.cs b/csharp/src/Google.Protobuf/WellKnownTypes/Type.cs
index dbc1ee0d..dbc1ee0d 100644
--- a/csharp/src/ProtocolBuffers/WellKnownTypes/Type.cs
+++ b/csharp/src/Google.Protobuf/WellKnownTypes/Type.cs
diff --git a/csharp/src/ProtocolBuffers/WellKnownTypes/Wrappers.cs b/csharp/src/Google.Protobuf/WellKnownTypes/Wrappers.cs
index c26f874d..c26f874d 100644
--- a/csharp/src/ProtocolBuffers/WellKnownTypes/Wrappers.cs
+++ b/csharp/src/Google.Protobuf/WellKnownTypes/Wrappers.cs
diff --git a/csharp/src/ProtocolBuffers/WireFormat.cs b/csharp/src/Google.Protobuf/WireFormat.cs
index c1712daa..c1712daa 100644
--- a/csharp/src/ProtocolBuffers/WireFormat.cs
+++ b/csharp/src/Google.Protobuf/WireFormat.cs
diff --git a/csharp/src/ProtocolBuffers.Test/Properties/OutOfBrowserSettings.xml b/csharp/src/ProtocolBuffers.Test/Properties/OutOfBrowserSettings.xml
deleted file mode 100644
index 634f44bf..00000000
--- a/csharp/src/ProtocolBuffers.Test/Properties/OutOfBrowserSettings.xml
+++ /dev/null
@@ -1,7 +0,0 @@
-<OutOfBrowserSettings ShortName="ProtocolBuffers.Test" EnableGPUAcceleration="False" ShowInstallMenuItem="False">
- <OutOfBrowserSettings.Blurb>ProtocolBuffers.Test</OutOfBrowserSettings.Blurb>
- <OutOfBrowserSettings.WindowSettings>
- <WindowSettings Title="ProtocolBuffers.Test" />
- </OutOfBrowserSettings.WindowSettings>
- <OutOfBrowserSettings.Icons />
-</OutOfBrowserSettings> \ No newline at end of file
diff --git a/csharp/src/packages/repositories.config b/csharp/src/packages/repositories.config
index 0117aa7c..70379412 100644
--- a/csharp/src/packages/repositories.config
+++ b/csharp/src/packages/repositories.config
@@ -1,5 +1,4 @@
<?xml version="1.0" encoding="utf-8"?>
<repositories>
- <repository path="..\ProtocolBuffers.Test\packages.config" />
- <repository path="..\ProtocolBuffersLite.Test\packages.config" />
+ <repository path="..\Google.Protobuf.Test\packages.config" />
</repositories> \ No newline at end of file
diff --git a/csharp/src/ProtoDump/Program.cs b/csharp/src/Google.Protobuf.JsonDump/Program.cs
index 6d42076d..99e60e90 100644
--- a/csharp/src/ProtoDump/Program.cs
+++ b/csharp/src/Google.Protobuf.JsonDump/Program.cs
@@ -36,7 +36,7 @@ using System.IO;
namespace Google.Protobuf.ProtoDump
{
/// <summary>
/// Small utility to load a binary message and dump it in text form
/// </summary>
internal class Program
{
@@ -44,7 +44,7 @@ namespace Google.Protobuf.ProtoDump
{
if (args.Length != 2)
{
- Console.Error.WriteLine("Usage: ProtoDump <descriptor type name> <input data>");
+ Console.Error.WriteLine("Usage: Google.Protobuf.JsonDump <descriptor type name> <input data>");
Console.Error.WriteLine("The descriptor type name is the fully-qualified message name,");
Console.Error.WriteLine("including assembly e.g. ProjectNamespace.Message,Company.Project");
return 1;
@@ -36,7 +36,7 @@ using System.IO;
{
/// <summary>
- /// Small utility to load a binary message and dump it in text form
+ /// Small utility to load a binary message and dump it in JSON format.
/// </summary>
internal class Program